==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/cs_CZ.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Sdílení mezi servery není povoleno",
    "The mountpoint name contains invalid characters." : "Jméno přípojného bodu obsahuje nepovolené znaky.",
    "Not allowed to create a federated share with the same user server" : "Není povoleno vytvořit propojené sdílení s tím samým serverem",
    "Invalid or untrusted SSL certificate" : "Neplatný nebo nedůvěryhodný SSL certifikát",
    "Could not authenticate to remote share, password might be wrong" : "Nezdařilo se ověření vzdáleného úložiště, pravděpodobně chybné heslo",
    "Storage not valid" : "Úložiště není platné",
    "Couldn't add remote share" : "Nelze přidat vzdálené úložiště",
    "Shared with you" : "Sdíleno s vámi",
    "Shared with others" : "Sdíleno s ostatními",
    "Shared by link" : "Sdíleno pomocí odkazu",
    "Anonymous upload" : "Nahrát anonymně",
    "Uploaded files" : "Nahrané soubory",
    "Uploading..." : "Odesílám...",
    "Nothing shared with you yet" : "Zatím s vámi nikdo nic nesdílel",
    "Files and folders others share with you will show up here" : "Zde budou zobrazeny soubory a adresáře, které s vámi ostatní sdílí",
    "Nothing shared yet" : "Zatím není nic sdíleno",
    "Files and folders you share will show up here" : "Zde budou zobrazeny vámi sdílené soubory a adresáře",
    "No shared links" : "Žádné sdílené odkazy",
    "Files and folders you share by link will show up here" : "Zde budou zobrazeny soubory a adresáře, které sdílíte jako webové odkazy",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Chcete přidat vzdálené úložiště {name} uživatele {owner}@{remote}?",
    "Remote share" : "Vzdálené úložiště",
    "Remote share password" : "Heslo ke vzdálenému úložišti",
    "Cancel" : "Zrušit",
    "Add remote share" : "Přidat vzdálené úložiště",
    "You can upload into this folder" : "Můžete nahrávat do tohoto adresáře",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nebyla nalezena instalace ownCloud (7 nebo vyšší) na {remote}",
    "Invalid ownCloud url" : "Neplatná ownCloud url",
    "Share" : "Sdílet",
    "No expiration date set" : "Není nastaveno datum vypršení platnosti",
    "Shared by" : "Sdílí",
    "Sharing" : "Sdílení",
    "Share API is disabled" : "Sdílení API je zakázané",
    "Wrong share ID, share doesn't exist" : "Špatné ID sdílení, sdílení neexistuje",
    "Could not delete share" : "Nelze smazat sdílení",
    "Please specify a file or folder path" : "Prosím zadejte cestu adresáře nebo souboru",
    "Wrong path, file/folder doesn't exist" : "Špatná cesta, soubor/adresář neexistuje",
    "Please specify a valid user" : "Prosím zadejte platného uživatele",
    "Group sharing is disabled by the administrator" : "Skupinové sdílení bylo zakázáno administrátorem",
    "Please specify a valid group" : "Prosím zadejte platnou skupinu",
    "Public link sharing is disabled by the administrator" : "Veřejný odkaz sdílení je zakázán administrátorem",
    "Public upload disabled by the administrator" : "Veřejné nahrávání zakázáno administrátorem",
    "Public upload is only possible for publicly shared folders" : "Veřejné nahrávání je možné pouze do veřejně sdílených adresářů",
    "Invalid date, date format must be YYYY-MM-DD" : "Neplatné datum, formát data musí být YYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Sdílení %s selhalo, podpůrná vrstva nepodporuje typ sdílení %s",
    "Unknown share type" : "Neznámý typ sdílení",
    "Not a directory" : "Žádný adresář",
    "Could not lock path" : "Nepodařilo se uzamknout cestu",
    "Can't change permissions for public share links" : "Nelze změnit oprávnění pro veřejně sdílené odkazy",
    "Wrong or no update parameter given" : "Chyba nebo žádná aktualizace dle zadaných parametrů",
    "Cannot increase permissions" : "Nelze navýšit oprávnění",
    "A file or folder has been <strong>shared</strong>" : "Soubor nebo adresář byl <strong>nasdílen</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Soubor nebo adresář byl nasdílen z <strong>jiného serveru</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Byl <strong>stažen</strong> veřejně sdílený soubor nebo adresář",
    "You received a new remote share %2$s from %1$s" : "Obdrželi jste nové vzdálené sdílení %2$s od uživatele %1$s",
    "You received a new remote share from %s" : "Obdrželi jste nové vzdálené sdílení z %s",
    "%1$s accepted remote share %2$s" : "%1$s přijal(a) vzdálené sdílení %2$s",
    "%1$s declined remote share %2$s" : "%1$s odmítl(a) vzdálené sdílení %2$s",
    "%1$s unshared %2$s from you" : "%1$s již více nesdílí %2$s",
    "Public shared folder %1$s was downloaded" : "Byl stažen veřejně sdílený adresář %1$s ",
    "Public shared file %1$s was downloaded" : "Byl stažen veřejně sdílený soubor %1$s ",
    "You shared %1$s with %2$s" : "Sdílíte %1$s s %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s nasdílel(a) %1$s s %3$s",
    "You removed the share of %2$s for %1$s" : "Odstranil(a) jsi sdílení %2$s pro %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s odstranil(a) sdílení %3$s pro %1$s",
    "You shared %1$s with group %2$s" : "Sdílíte %1$s se skupinou %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s nasdílel(a) %1$s se skupinou %3$s",
    "You removed the share of group %2$s for %1$s" : "Odstranil(a) jsi sdílení skupině %2$s pro %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s odstranil(a) sdílení skupině %3$s pro %1$s",
    "%2$s shared %1$s via link" : "%2$s nasdílel(a) %1$s jako odkaz",
    "You shared %1$s via link" : "Sdílíte %1$s přes odkaz",
    "You removed the public link for %1$s" : "Odstranil(a) jsi veřejný odkaz na %1$s",
    "%2$s removed the public link for %1$s" : "%2$s odstranil(a) veřejný odkaz na %1$s",
    "Your public link for %1$s expired" : "Veřejný odkaz pro %1$s vypršel",
    "The public link of %2$s for %1$s expired" : "Veřejný odkaz na %2$s pro %1$s vypršel",
    "%2$s shared %1$s with you" : "%2$s s vámi sdílí %1$s",
    "%2$s removed the share for %1$s" : "%2$s odstranil(a) sdílení pro %1$s",
    "Downloaded via public link" : "Staženo pomocí veřejného odkazu",
    "Shared with %2$s" : "Sdíleno s %2$s",
    "Shared with %3$s by %2$s" : "%2$s sdílí s %3$s",
    "Removed share for %2$s" : "Odstranil(a) sdílení pro %2$s",
    "%2$s removed share for %3$s" : "%2$s odstranil(a) sdílení pro %3$s",
    "Shared with group %2$s" : "Sdíleno se skupinou %2$s",
    "Shared with group %3$s by %2$s" : "%2$s sdílí se skupinou %3$s",
    "Removed share of group %2$s" : "Odstranil(a) sdílení skupině %2$s",
    "%2$s removed share of group %3$s" : "%2$s odstranil(a) sdílení skupině %3$s",
    "Shared via link by %2$s" : "%2$s sdílel(a) jako odkaz",
    "Shared via public link" : "Sdíleno jako veřejný odkaz",
    "Removed public link" : "Odstranil(a) veřejný odkaz",
    "%2$s removed public link" : "%2$s odstranil(a) veřejný odkaz",
    "Public link expired" : "Veřejný odkaz vypršel",
    "Public link of %2$s expired" : "Veřejný odkaz %2$s vypršel",
    "Shared by %2$s" : "%2$s sdílel(a)",
    "Shares" : "Sdílení",
    "This share is password-protected" : "Toto sdílení je chráněno heslem",
    "The password is wrong. Try again." : "Heslo není správné. Zkuste to znovu.",
    "Password" : "Heslo",
    "No entries found in this folder" : "V tomto adresáři nebylo nic nalezeno",
    "Name" : "Název",
    "Share time" : "Čas sdílení",
    "Expiration date" : "Datum vypršení platnosti",
    "Sorry, this link doesn’t seem to work anymore." : "Je nám líto, ale tento odkaz již není funkční.",
    "Reasons might be:" : "Možné důvody:",
    "the item was removed" : "položka byla odebrána",
    "the link expired" : "platnost odkazu vypršela",
    "sharing is disabled" : "sdílení je zakázané",
    "For more info, please ask the person who sent this link." : "Pro více informací kontaktujte osobu, která vám zaslala tento odkaz.",
    "%s is publicly shared" : "%s je veřejně sdílen",
    "Add to your ownCloud" : "Přidat do svého ownCloudu",
    "Download" : "Stáhnout",
    "Download %s" : "Stáhnout %s",
    "Direct link" : "Přímý odkaz"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> owncloud-10.0.10.tgz: owncloud/apps/files_sharing/l10n/cs_CZ.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Sdílení mezi servery není povoleno",
    "The mountpoint name contains invalid characters." : "Jméno přípojného bodu obsahuje nepovolené znaky.",
    "Not allowed to create a federated share with the same user server" : "Není povoleno vytvořit propojené sdílení s tím samým serverem",
    "Invalid or untrusted SSL certificate" : "Neplatný nebo nedůvěryhodný SSL certifikát",
    "Could not authenticate to remote share, password might be wrong" : "Nezdařilo se ověření vzdáleného úložiště, pravděpodobně chybné heslo",
    "Storage not valid" : "Úložiště není platné",
    "Couldn't add remote share" : "Nelze přidat vzdálené úložiště",
    "Shared with you" : "Sdíleno s vámi",
    "Shared with others" : "Sdíleno s ostatními",
    "Shared by link" : "Sdíleno pomocí odkazu",
    "Anonymous upload" : "Nahrát anonymně",
    "Uploaded files" : "Nahrané soubory",
    "Uploading..." : "Odesílám...",
    "Nothing shared with you yet" : "Zatím s vámi nikdo nic nesdílel",
    "Files and folders others share with you will show up here" : "Zde budou zobrazeny soubory a adresáře, které s vámi ostatní sdílí",
    "Nothing shared yet" : "Zatím není nic sdíleno",
    "Files and folders you share will show up here" : "Zde budou zobrazeny vámi sdílené soubory a adresáře",
    "No shared links" : "Žádné sdílené odkazy",
    "Files and folders you share by link will show up here" : "Zde budou zobrazeny soubory a adresáře, které sdílíte jako webové odkazy",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Chcete přidat vzdálené úložiště {name} uživatele {owner}@{remote}?",
    "Remote share" : "Vzdálené úložiště",
    "Remote share password" : "Heslo ke vzdálenému úložišti",
    "Cancel" : "Zrušit",
    "Add remote share" : "Přidat vzdálené úložiště",
    "You can upload into this folder" : "Můžete nahrávat do tohoto adresáře",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nebyla nalezena instalace ownCloud (7 nebo vyšší) na {remote}",
    "Invalid ownCloud url" : "Neplatná ownCloud url",
    "Share" : "Sdílet",
    "No expiration date set" : "Není nastaveno datum vypršení platnosti",
    "Shared by" : "Sdílí",
    "Sharing" : "Sdílení",
    "Share API is disabled" : "Sdílení API je zakázané",
    "Wrong share ID, share doesn't exist" : "Špatné ID sdílení, sdílení neexistuje",
    "Could not delete share" : "Nelze smazat sdílení",
    "Please specify a file or folder path" : "Prosím zadejte cestu adresáře nebo souboru",
    "Wrong path, file/folder doesn't exist" : "Špatná cesta, soubor/adresář neexistuje",
    "Please specify a valid user" : "Prosím zadejte platného uživatele",
    "Group sharing is disabled by the administrator" : "Skupinové sdílení bylo zakázáno administrátorem",
    "Please specify a valid group" : "Prosím zadejte platnou skupinu",
    "Public link sharing is disabled by the administrator" : "Veřejný odkaz sdílení je zakázán administrátorem",
    "Public upload disabled by the administrator" : "Veřejné nahrávání zakázáno administrátorem",
    "Public upload is only possible for publicly shared folders" : "Veřejné nahrávání je možné pouze do veřejně sdílených adresářů",
    "Invalid date, date format must be YYYY-MM-DD" : "Neplatné datum, formát data musí být YYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Sdílení %s selhalo, podpůrná vrstva nepodporuje typ sdílení %s",
    "Unknown share type" : "Neznámý typ sdílení",
    "Not a directory" : "Žádný adresář",
    "Could not lock path" : "Nepodařilo se uzamknout cestu",
    "Can't change permissions for public share links" : "Nelze změnit oprávnění pro veřejně sdílené odkazy",
    "Wrong or no update parameter given" : "Chyba nebo žádná aktualizace dle zadaných parametrů",
    "Cannot increase permissions" : "Nelze navýšit oprávnění",
    "A file or folder has been <strong>shared</strong>" : "Soubor nebo adresář byl <strong>nasdílen</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Soubor nebo adresář byl nasdílen z <strong>jiného serveru</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Byl <strong>stažen</strong> veřejně sdílený soubor nebo adresář",
    "You received a new remote share %2$s from %1$s" : "Obdrželi jste nové vzdálené sdílení %2$s od uživatele %1$s",
    "You received a new remote share from %s" : "Obdrželi jste nové vzdálené sdílení z %s",
    "%1$s accepted remote share %2$s" : "%1$s přijal(a) vzdálené sdílení %2$s",
    "%1$s declined remote share %2$s" : "%1$s odmítl(a) vzdálené sdílení %2$s",
    "%1$s unshared %2$s from you" : "%1$s již více nesdílí %2$s",
    "Public shared folder %1$s was downloaded" : "Byl stažen veřejně sdílený adresář %1$s ",
    "Public shared file %1$s was downloaded" : "Byl stažen veřejně sdílený soubor %1$s ",
    "You shared %1$s with %2$s" : "Sdílíte %1$s s %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s nasdílel(a) %1$s s %3$s",
    "You removed the share of %2$s for %1$s" : "Odstranil(a) jsi sdílení %2$s pro %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s odstranil(a) sdílení %3$s pro %1$s",
    "You shared %1$s with group %2$s" : "Sdílíte %1$s se skupinou %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s nasdílel(a) %1$s se skupinou %3$s",
    "You removed the share of group %2$s for %1$s" : "Odstranil(a) jsi sdílení skupině %2$s pro %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s odstranil(a) sdílení skupině %3$s pro %1$s",
    "%2$s shared %1$s via link" : "%2$s nasdílel(a) %1$s jako odkaz",
    "You shared %1$s via link" : "Sdílíte %1$s přes odkaz",
    "You removed the public link for %1$s" : "Odstranil(a) jsi veřejný odkaz na %1$s",
    "%2$s removed the public link for %1$s" : "%2$s odstranil(a) veřejný odkaz na %1$s",
    "Your public link for %1$s expired" : "Veřejný odkaz pro %1$s vypršel",
    "The public link of %2$s for %1$s expired" : "Veřejný odkaz na %2$s pro %1$s vypršel",
    "%2$s shared %1$s with you" : "%2$s s vámi sdílí %1$s",
    "%2$s removed the share for %1$s" : "%2$s odstranil(a) sdílení pro %1$s",
    "Downloaded via public link" : "Staženo pomocí veřejného odkazu",
    "Shared with %2$s" : "Sdíleno s %2$s",
    "Shared with %3$s by %2$s" : "%2$s sdílí s %3$s",
    "Removed share for %2$s" : "Odstranil(a) sdílení pro %2$s",
    "%2$s removed share for %3$s" : "%2$s odstranil(a) sdílení pro %3$s",
    "Shared with group %2$s" : "Sdíleno se skupinou %2$s",
    "Shared with group %3$s by %2$s" : "%2$s sdílí se skupinou %3$s",
    "Removed share of group %2$s" : "Odstranil(a) sdílení skupině %2$s",
    "%2$s removed share of group %3$s" : "%2$s odstranil(a) sdílení skupině %3$s",
    "Shared via link by %2$s" : "%2$s sdílel(a) jako odkaz",
    "Shared via public link" : "Sdíleno jako veřejný odkaz",
    "Removed public link" : "Odstranil(a) veřejný odkaz",
    "%2$s removed public link" : "%2$s odstranil(a) veřejný odkaz",
    "Public link expired" : "Veřejný odkaz vypršel",
    "Public link of %2$s expired" : "Veřejný odkaz %2$s vypršel",
    "Shared by %2$s" : "%2$s sdílel(a)",
    "Shares" : "Sdílení",
    "This share is password-protected" : "Toto sdílení je chráněno heslem",
    "The password is wrong. Try again." : "Heslo není správné. Zkuste to znovu.",
    "Password" : "Heslo",
    "No entries found in this folder" : "V tomto adresáři nebylo nic nalezeno",
    "Name" : "Název",
    "Share time" : "Čas sdílení",
    "Expiration date" : "Datum vypršení platnosti",
    "Sorry, this link doesn’t seem to work anymore." : "Je nám líto, ale tento odkaz již není funkční.",
    "Reasons might be:" : "Možné důvody:",
    "the item was removed" : "položka byla odebrána",
    "the link expired" : "platnost odkazu vypršela",
    "sharing is disabled" : "sdílení je zakázané",
    "For more info, please ask the person who sent this link." : "Pro více informací kontaktujte osobu, která vám zaslala tento odkaz.",
    "%s is publicly shared" : "%s je veřejně sdílen",
    "Add to your ownCloud" : "Přidat do svého ownCloudu",
    "Download" : "Stáhnout",
    "Download %s" : "Stáhnout %s",
    "Direct link" : "Přímý odkaz",
    "Click to select files or use drag & drop to upload" : "Vyberte soubor nebo použijte táhni a pusť k nahrání",
    "Cannot remove all permissions" : "Nelze odstranit všechna oprávnění",
    "Pending" : "Nevyřízené",
    "Accept" : "Přijmout",
    "Decline" : "Zamítnout",
    "Declined" : "Zamítnuto"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
